library(data.table)
library(dplyr)
d <- fread("anchor_pairs_contact_reads_kr_raw.txt")
##remove anchor pairs supported by less than 2 contact read pairs 
d <- filter(d,raw>1)
r1 <- d[,c(1:2)]
r2 <- d[,c(4:5)]
names(r2) <- names(r1)
region <- rbind(r1,r2)
region_count <- group_by(region,chr1,start1)%>%
		count()
dat <- left_join(d,region_count,by=c("chr1","start1"))%>%
	left_join(region_count,by=c("chr2"="chr1","start2"="start1"))%>%
	mutate(count=n.x+n.y)
dat <- na.omit(dat)
##cdf plot show the cumulative distribution of each region's interacted site counts
library(ggplot2)
p <- ggplot(dat,aes(count))+stat_ecdf(geom="step",size=1.5,color="#f47a7f")+xlim(0,500)
ggsave("count_cdf.png")
##remove the regions that interacted with multiple consecutive sites(here set to 20)
dat_f <- filter(dat,count<20)
n1=quantile(dat_f$raw,0.9)
n2=quantile(dat_f$kr,0.9)
dat_f <- filter(dat_f,raw>n1&kr>n2)
write.table(dat_f[,c(1:6)],"anchor_pairs_contact_reads_kr_raw.filter.txt",quote=F,sep="\t",col.names=F,row.names=F)
